@@ -18,9 +18,9 @@
 
 Bazaar can be used with Subversion branches through the bzr-svn plugin.
 
-Most Bazaar commands should work fine with Subversion branches. 
+Most Bazaar commands should work fine with Subversion branches.
 
-bzr-svn also adds four new commands to Bazaar:
+bzr-svn also adds new commands to Bazaar:
 
  - bzr svn-import
  - bzr svn-layout
@@ -31,10 +31,11 @@ For more information about bzr-svn, see the bzr-svn FAQ.
 import bzrlib
 import bzrlib.api
 
-# versions ending in 'exp' mean experimental mappings
-# versions ending in 'dev' mean development version
-# versions ending in 'final' mean release (well tested, etc)
-version_info = (0, 6, 2, 'final', 0)
+from info import (
+    bzr_plugin_version as version_info,
+    bzr_compatible_versions,
+    subvertpy_minimum_version,
+    )
 
 if version_info[3] == 'final':
     version_string = '%d.%d.%d' % version_info[:3]
@@ -42,10 +43,7 @@ else:
     version_string = '%d.%d.%d%s%d' % version_info
 __version__ = version_string
 
-COMPATIBLE_BZR_VERSIONS = [(1, 15, 0), (1, 16, 0), (1, 17, 0)]
-MINIMUM_SUBVERTPY_VERSION = (0, 6, 1)
-
-bzrlib.api.require_any_api(bzrlib, COMPATIBLE_BZR_VERSIONS)
+bzrlib.api.require_any_api(bzrlib, bzr_compatible_versions)
 
 
 from bzrlib import config
@@ -61,6 +59,7 @@ from bzrlib.commands import (
     )
 from bzrlib.errors import (
     DependencyNotPresent,
+    InvalidRevisionId,
     )
 from bzrlib.filters import (
     lazy_register_filter_stack_map,
@@ -97,7 +96,7 @@ def check_subversion_version():
     # Installed ?
     from subvertpy import ra, __version__ as subvertpy_version
     ra_version = ra.version()
-    if (ra_version[0] >= 5 and getattr(ra, 'SVN_REVISION', None) and 
+    if (ra_version[0] >= 5 and getattr(ra, 'SVN_REVISION', None) and
         27729 <= ra.SVN_REVISION < 31470):
         raise DependencyNotPresent("subvertpy",
                 'bzr-svn: Installed Subversion has buggy svn.ra.get_log() '
@@ -105,8 +104,8 @@ def check_subversion_version():
 
     mutter("bzr-svn: using Subversion %d.%d.%d (%s)" % ra_version)
 
-    if subvertpy_version < MINIMUM_SUBVERTPY_VERSION:
-        raise DependencyNotPresent("subvertpy", "bzr-svn: at least subvertpy %d.%d.%d is required, %d.%d.%d is installed." % (MINIMUM_SUBVERTPY_VERSION + subvertpy_version))
+    if subvertpy_version < subvertpy_minimum_version:
+        raise DependencyNotPresent("subvertpy", "bzr-svn: at least subvertpy %d.%d.%d is required, %d.%d.%d is installed." % (subvertpy_minimum_version + subvertpy_version))
 
 
 def get_client_string():
@@ -116,7 +115,7 @@ def get_client_string():
 
 def init_subvertpy():
     try:
-        import subvertpy 
+        import subvertpy
     except ImportError, e:
         raise DependencyNotPresent("subvertpy", "bzr-svn: %s" % e.message)
 
@@ -129,7 +128,7 @@ def init_subvertpy():
 _versions_checked = False
 def lazy_check_versions():
     """Check whether all dependencies have the right versions.
-    
+
     :note: Only checks once, caches the result."""
     global _versions_checked
     if _versions_checked:
@@ -139,29 +138,24 @@ def lazy_check_versions():
 
 from bzrlib.plugins.svn import format
 
-register_transport_proto('svn+ssh://', 
+register_transport_proto('svn+ssh://',
     help="Access using the Subversion smart server tunneled over SSH.")
-register_transport_proto('svn+file://', 
-    help="Access of local Subversion repositories.")
 register_transport_proto('svn+http://',
     help="Access of Subversion smart servers over HTTP.")
 register_transport_proto('svn+https://',
     help="Access of Subversion smart servers over secure HTTP.")
-register_transport_proto('svn://', 
+register_transport_proto('svn://',
     help="Access using the Subversion smart server.")
-register_lazy_transport('svn://', 'bzrlib.plugins.svn.transport', 
+register_lazy_transport('svn://', 'bzrlib.plugins.svn.transport',
                         'SvnRaTransport')
-register_lazy_transport('svn+', 'bzrlib.plugins.svn.transport', 
+register_lazy_transport('svn+', 'bzrlib.plugins.svn.transport',
                         'SvnRaTransport')
-topic_registry.register_lazy('svn-branching-schemes', 
-                             'bzrlib.plugins.svn.mapping3',
-                             'help_schemes', 'Subversion branching schemes')
-topic_registry.register_lazy('svn-layout', 
+topic_registry.register_lazy('svn-layout',
                              'bzrlib.plugins.svn.layout',
                              'help_layout', 'Subversion repository layouts')
 #BzrDirFormat.register_control_server_format(format.SvnRemoteFormat)
 # Register as the first control server format, since the default smart
-# server implementation tries to do a POST request against .bzr/smart and 
+# server implementation tries to do a POST request against .bzr/smart and
 # this causes some Subversion servers to reply with 401 Authentication required
 # even though they are accessible without authentication.
 BzrDirFormat._control_server_formats.insert(0, format.SvnRemoteFormat)
@@ -171,44 +165,35 @@ branch_network_format_registry.register_lazy("subversion",
 repository_network_format_registry.register_lazy("subversion",
         'bzrlib.plugins.svn.repository', 'SvnRepositoryFormat')
 
-format_registry.register_lazy("subversion", "bzrlib.plugins.svn.format", 
-                         "SvnRemoteFormat", 
-                         "Subversion repository. ", 
+format_registry.register_lazy("subversion", "bzrlib.plugins.svn.format",
+                         "SvnRemoteFormat",
+                         "Subversion repository. ",
                          native=False)
-format_registry.register_lazy("subversion-wc", "bzrlib.plugins.svn.format", 
-                         "SvnWorkingTreeDirFormat", 
-                         "Subversion working copy. ", 
+format_registry.register_lazy("subversion-wc", "bzrlib.plugins.svn.format",
+                         "SvnWorkingTreeDirFormat",
+                         "Subversion working copy. ",
                          native=False, hidden=True)
-revspec_registry.register_lazy("svn:", "bzrlib.plugins.svn.revspec", 
+revspec_registry.register_lazy("svn:", "bzrlib.plugins.svn.revspec",
     "RevisionSpec_svn")
 
-try:
-    config.credential_store_registry.register_lazy(
-        "subversion", "bzrlib.plugins.svn.auth", "SubversionCredentialStore", 
-        help=__doc__, fallback=True)
-except TypeError:
-    # Fallback credentials stores were introduced in Bazaar 1.15
-    config.credential_store_registry.register_lazy(
-        "subversion", "bzrlib.plugins.svn.auth", "SubversionCredentialStore", 
-        help=__doc__)
+config.credential_store_registry.register_lazy(
+    "subversion", "bzrlib.plugins.svn.auth", "SubversionCredentialStore",
+    help=__doc__, fallback=True)
 
 foreign_vcs_registry.register_lazy("svn", "bzrlib.plugins.svn.mapping",
                                    "foreign_vcs_svn")
 
-try:
-    from bzrlib.transport import transport_server_registry
-except ImportError:
-    pass
-else:
-    transport_server_registry.register_lazy('svn', 
-        'bzrlib.plugins.svn.server', 'serve_svn', 
-        "Subversion svn_ra protocol. (default port: 3690)")
+from bzrlib.transport import transport_server_registry
+transport_server_registry.register_lazy('svn',
+    'bzrlib.plugins.svn.server', 'serve_svn',
+    "Subversion svn_ra protocol. (default port: 3690)")
+
 
 _optimizers_registered = False
 def lazy_register_optimizers():
-    """Register optimizers for fetching between Subversion and Bazaar 
+    """Register optimizers for fetching between Subversion and Bazaar
     repositories.
-    
+
     :note: Only registers on the first call."""
     global _optimizers_registered
     if _optimizers_registered:
@@ -221,12 +206,12 @@ def lazy_register_optimizers():
 
 
 plugin_cmds.register_lazy('cmd_svn_import', [], 'bzrlib.plugins.svn.commands')
-plugin_cmds.register_lazy('cmd_svn_branching_scheme', [], 
+plugin_cmds.register_lazy('cmd_svn_branching_scheme', [],
                           'bzrlib.plugins.svn.mapping3.commands')
-plugin_cmds.register_lazy('cmd_svn_layout', [], 
+plugin_cmds.register_lazy('cmd_svn_layout', [],
                           'bzrlib.plugins.svn.commands')
 
-lazy_register_filter_stack_map("svn-keywords", 
+lazy_register_filter_stack_map("svn-keywords",
         "bzrlib.plugins.svn.keywords", "create_svn_keywords_filter")
 
 
@@ -237,29 +222,38 @@ def info_svn_repository(repository, stats, outf):
         outf.write("Subversion Last Revision: %d\n" % stats["svn-last-revnum"])
 
 
-try:
-    from bzrlib.info import (
-        hooks as info_hooks,
-        )
-except ImportError:
-    # Info hooks were introduced in Bazaar 1.15
-    pass
-else:
-    info_hooks.install_named_hook('repository', info_svn_repository, None)
+from bzrlib.info import hooks as info_hooks
+info_hooks.install_named_hook('repository', info_svn_repository, None)
 
 
 def update_stanza(rev, stanza):
     revmeta = getattr(rev, "svn_meta", None)
-    if revmeta is None:
-        return
-    stanza.add("svn-revno", str(revmeta.revnum))
-    stanza.add("svn-uuid", revmeta.uuid)
+    if revmeta is not None:
+        stanza.add("svn-revno", str(revmeta.revnum))
+        stanza.add("svn-uuid", revmeta.uuid)
+    else:
+        from bzrlib.plugins.svn.mapping import mapping_registry
+        from bzrlib.plugins.svn import errors as svn_errors
+        try:
+            (uuid, branch_path, revno), mapping = \
+                mapping_registry.parse_revision_id(rev.revision_id)
+        except InvalidRevisionId:
+            pass
+        else:
+            stanza.add("svn-revno", str(revno))
+            stanza.add("svn-uuid", uuid)
 
 
 RioVersionInfoBuilder.hooks.install_named_hook('revision',
     update_stanza, None)
 
 
+from bzrlib.send import format_registry as send_format_registry
+
+send_format_registry.register_lazy('svn', 'bzrlib.plugins.svn.send',
+                                   'send_svn', 'Subversion diff format')
+
+
 def test_suite():
     """Returns the testsuite for bzr-svn."""
     from unittest import TestSuite
