@@ -21,7 +21,6 @@ import threading
 
 import bzrlib
 from bzrlib import (
-    debug, 
     osutils,
     trace,
     )
@@ -55,7 +54,7 @@ See http://bazaar-vcs.org/BzrForeignBranches/Subversion for details.
 
 def create_cache_dir():
     """Create the top-level bzr-svn cache directory.
-    
+
     :return: Path to cache directory.
     """
     ensure_config_dir_exists()
@@ -85,6 +84,8 @@ def create_cache_dir():
             pass
         else:
             cache_dir = os.path.join(xdg_cache_home, "bazaar", "svn")
+            if type(cache_dir) == unicode:
+                cache_dir = cache_dir.encode(osutils._fs_enc)
 
     if not os.path.exists(cache_dir):
         os.makedirs(cache_dir)
@@ -111,9 +112,10 @@ class RepositoryCache(object):
 
     def create_cache_dir(self):
         cache_dir = create_cache_dir()
+        assert isinstance(cache_dir, str)
         dir = os.path.join(cache_dir, self.uuid)
         if not os.path.exists(dir):
-            trace.info("Initialising Subversion metadata cache in %s.",
+            trace.note("Initialising Subversion metadata cache in %s.",
                        dir.decode(osutils._fs_enc))
             os.mkdir(dir)
         return dir
