@@ -28,15 +28,21 @@ from bzrlib.errors import (
     ConnectionReset,
     DivergedBranches,
     InvalidRevisionSpec,
-    LockError,
+    LockActive,
     PermissionDenied,
     NoRepositoryPresent,
     NoSuchRevision,
+    TipChangeRejected,
     TransportError,
     UnexpectedEndOfContainerError,
+    VersionedFileInvalidChecksum,
     )
 
 
+ERR_RA_DAV_PROPPATCH_FAILED = getattr(subvertpy, "ERR_RA_DAV_PROPPATCH_FAILED", 175008)
+ERR_EAI_NONAME = getattr(subvertpy, "ERR_EAI_NONAME", 670008)
+
+
 class InvalidBzrSvnRevision(NoSuchRevision):
     _fmt = """Revision id %(revid)s was added incorrectly"""
 
@@ -46,7 +52,7 @@ class InvalidBzrSvnRevision(NoSuchRevision):
 
 class NotSvnBranchPath(BzrError):
     """Error raised when a path was specified that did not exist."""
-    _fmt = """%(branch_path)s is not a valid Subversion branch path. 
+    _fmt = """%(branch_path)s is not a valid Subversion branch path.
 See 'bzr help svn-layout' for details."""
 
     def __init__(self, branch_path, mapping=None):
@@ -76,7 +82,7 @@ class MissingPrefix(BzrError):
 
 
 class RevpropChangeFailed(BzrError):
-    _fmt = """Unable to set revision property %(name)s. 
+    _fmt = """Unable to set revision property %(name)s.
 Does the repository pre-revprop-change hook allow property changes?"""
 
     def __init__(self, name):
@@ -103,7 +109,7 @@ def convert_error(err):
     if num == subvertpy.ERR_RA_SVN_CONNECTION_CLOSED:
         return ConnectionReset(msg=msg)
     elif num == subvertpy.ERR_WC_LOCKED:
-        return LockError(message=msg)
+        return LockActive(msg)
     elif num == subvertpy.ERR_RA_NOT_AUTHORIZED:
         return PermissionDenied('.', msg)
     elif num == subvertpy.ERR_INCOMPLETE_DATA:
@@ -114,14 +120,20 @@ def convert_error(err):
         return NotImplementedError("Function not implemented in remote server")
     elif num == subvertpy.ERR_UNKNOWN_HOSTNAME:
         return ConnectionError(msg=msg)
+    elif num == ERR_EAI_NONAME:
+        return ConnectionError(msg=msg)
     elif num == subvertpy.ERR_RA_DAV_REQUEST_FAILED:
         return DavRequestFailed(msg)
+    elif num == subvertpy.ERR_REPOS_HOOK_FAILURE:
+        return TipChangeRejected(msg)
+    if num == ERR_RA_DAV_PROPPATCH_FAILED:
+        return PropertyChangeFailed(msg)
     else:
         return err
 
 
 def convert_svn_error(unbound):
-    """Decorator that catches particular Subversion exceptions and 
+    """Decorator that catches particular Subversion exceptions and
     converts them to Bazaar exceptions.
     """
     def convert(*args, **kwargs):
@@ -221,7 +233,7 @@ class UnknownMapping(BzrError):
 class AbsentPath(BzrError):
 
     _fmt = """Unable to access %(path)s: no permission?. """
-    
+
     def __init__(self, path):
         BzrError.__init__(self, path=path)
 
@@ -247,3 +259,22 @@ class PushToEmptyBranch(DivergedBranches):
     _fmt = ("Empty branch already exists at /trunk. "
             "Specify --overwrite or remove it before pushing.")
 
+
+class PropertyChangeFailed(BzrError):
+
+    _fmt = """Unable to set DAV properties: %(msg)s. Perhaps LimitXMLRequestBody is set too low in the server."""
+
+    def __init__(self, msg):
+        BzrError.__init__(self, msg=msg)
+
+
+class TextChecksumMismatch(VersionedFileInvalidChecksum):
+
+    _fmt = """checksum mismatch: %(expected_checksum)r != %(actual_checksum)r in %(path)s:%(revnum)d"""
+
+    def __init__(self, expected_checksum, actual_checksum, path, revnum):
+        self.expected_checksum = expected_checksum
+        self.actual_checksum = actual_checksum
+        self.path = path
+        self.revnum = revnum
+
