@@ -20,6 +20,7 @@
 
 from bzrlib import (
     errors as bzr_errors,
+    osutils,
     trace,
     )
 from bzrlib.bzrdir import (
@@ -32,20 +33,12 @@ from bzrlib.lockable_files import (
 
 
 def get_rich_root_format(stacked=False):
-    if not stacked:
-        return format_registry.make_bzrdir('default-rich-root')
-    else:
+    format = format_registry.make_bzrdir('default-rich-root')
+    # If the default format does not support stacking, fall back to
+    # 1.9-rr. This doesn't have performance issues, since all
+    # bzr versions that have 2a as default.
+    if stacked and not format.get_branch_format().supports_stacking():
         return format_registry.make_bzrdir('1.9-rich-root')
-
-
-def get_nested_tree_format():
-    format = BzrDirFormat.get_default_format()
-    if format.repository_format.supports_tree_reference:
-        return format
-    # Default format does not support rich root data, 
-    # fall back to development-subtree
-    format = format_registry.make_bzrdir('development-subtree')
-    assert format.repository_format.supports_tree_reference
     return format
 
 
@@ -73,7 +66,7 @@ class SvnControlFormat(BzrDirFormat):
     def is_supported(self):
         """See BzrDir.is_supported()."""
         return True
- 
+
 
 class SvnRemoteFormat(SvnControlFormat):
     """Format for the Subversion smart server."""
@@ -113,12 +106,18 @@ class SvnRemoteFormat(SvnControlFormat):
             if num in (subvertpy.ERR_RA_ILLEGAL_URL, \
                        subvertpy.ERR_RA_LOCAL_REPOS_OPEN_FAILED, \
                        subvertpy.ERR_BAD_URL):
-                trace.mutter("Unable to open %r with Subversion: %s", 
+                trace.mutter("Unable to open %r with Subversion: %s",
                     transport, msg)
                 raise bzr_errors.NotBranchError(path=transport.base)
             raise
+        except bzr_errors.InProcessTransport:
+            raise bzr_errors.NotBranchError(path=transport.base)
+        except bzr_errors.NoSuchFile:
+            raise bzr_errors.NotBranchError(path=transport.base)
         except bzr_errors.InvalidURL:
             raise bzr_errors.NotBranchError(path=transport.base)
+        except bzr_errors.InvalidHttpResponse:
+            raise bzr_errors.NotBranchError(path=transport.base)
         except DavRequestFailed, e:
             if "501 Unsupported method" in e.msg:
                 raise bzr_errors.NotBranchError(path=transport.base)
@@ -132,15 +131,15 @@ class SvnRemoteFormat(SvnControlFormat):
         import subvertpy
         from bzrlib.plugins.svn import remote
         ERR_XML_MALFORMED = getattr(subvertpy, "ERR_XML_MALFORMED", 130003)
-        try: 
+        try:
             return remote.SvnRemoteAccess(transport, self)
         except subvertpy.SubversionException, (_, num):
-            if num in (subvertpy.ERR_RA_DAV_REQUEST_FAILED, 
+            if num in (subvertpy.ERR_RA_DAV_REQUEST_FAILED,
                        subvertpy.ERR_RA_DAV_NOT_VCC):
                 raise bzr_errors.NotBranchError(transport.base)
             if num == ERR_XML_MALFORMED:
-                # This *could* be an indication of an actual corrupt 
-                # svn server, but usually it just means a broken 
+                # This *could* be an indication of an actual corrupt
+                # svn server, but usually it just means a broken
                 # xml page
                 raise bzr_errors.NotBranchError(transport.base)
             raise
@@ -160,11 +159,12 @@ class SvnRemoteFormat(SvnControlFormat):
         from subvertpy import repos
 
         if not isinstance(transport, LocalTransport):
-            raise NotImplementedError(self.initialize, 
+            raise NotImplementedError(self.initialize,
                 "Can't create Subversion Repositories/branches on "
                 "non-local transports")
 
-        local_path = transport._local_base.rstrip("/")
+        local_path = transport.local_abspath(".").rstrip("/").encode(osutils._fs_enc)
+        assert type(local_path) == str
         repos.create(local_path)
         # All revision property changes
         revprop_hook = os.path.join(local_path, "hooks", "pre-revprop-change")
