@@ -21,7 +21,6 @@ except ImportError:
     from bzrlib.plugins.svn.pycompat import defaultdict
 
 from itertools import chain
-import os
 import subvertpy
 
 ERR_RA_DAV_FORBIDDEN = getattr(subvertpy, "ERR_RA_DAV_FORBIDDEN", 175013)
@@ -30,34 +29,34 @@ from bzrlib import (
     branch,
     errors as bzr_errors,
     graph,
-    osutils,
+    transactions,
     ui,
     urlutils,
     )
-from bzrlib.foreign import ForeignRepository
-from bzrlib.inventory import Inventory
-from bzrlib.lockable_files import (
-    LockableFiles,
-    TransportLock,
+from bzrlib.foreign import (
+    ForeignRepository,
+    )
+from bzrlib.inventory import (
+    Inventory,
     )
 from bzrlib.repository import (
     Repository,
     RepositoryFormat,
     needs_read_lock,
     )
-from bzrlib.revisiontree import RevisionTree
+from bzrlib.revisiontree import (
+    RevisionTree,
+    )
 from bzrlib.revision import (
     NULL_REVISION,
     ensure_null,
     )
 from bzrlib.trace import (
-    info,
     mutter,
     note,
     )
 from bzrlib.transport import (
     Transport,
-    get_transport,
     )
 
 from bzrlib.plugins.svn import (
@@ -68,15 +67,23 @@ from bzrlib.plugins.svn import (
     logwalker,
     revmeta,
     )
-from bzrlib.plugins.svn.branchprops import PathPropertyProvider
-from bzrlib.plugins.svn.config import SvnRepositoryConfig
+from bzrlib.plugins.svn.branchprops import (
+    PathPropertyProvider,
+    )
+from bzrlib.plugins.svn.config import (
+    SvnRepositoryConfig,
+    )
 from bzrlib.plugins.svn.fileids import (
     CachingFileIdMapStore,
     FileIdMapStore,
     simple_apply_changes,
     )
-from bzrlib.plugins.svn.layout.standard import WildcardLayout
-from bzrlib.plugins.svn.layout.guess import repository_guess_layout
+from bzrlib.plugins.svn.layout.standard import (
+    WildcardLayout,
+    )
+from bzrlib.plugins.svn.layout.guess import (
+    repository_guess_layout,
+    )
 from bzrlib.plugins.svn.mapping import (
     SVN_REVPROP_BZR_SIGNATURE,
     BzrSvnMapping,
@@ -87,15 +94,20 @@ from bzrlib.plugins.svn.mapping import (
     mapping_registry,
     parse_svn_dateprop,
     )
-from bzrlib.plugins.svn.parents import DiskCachingParentsProvider
+from bzrlib.plugins.svn.parents import (
+    DiskCachingParentsProvider,
+    )
 from bzrlib.plugins.svn.revids import (
     DiskCachingRevidMap,
     MemoryCachingRevidMap,
     RevidMap,
-    RevisionInfoCache,
     )
-from bzrlib.plugins.svn.tree import SvnRevisionTree
-from bzrlib.plugins.svn.versionedfiles import SvnTexts
+from bzrlib.plugins.svn.tree import (
+    SvnRevisionTree,
+    )
+from bzrlib.plugins.svn.versionedfiles import (
+    SvnTexts,
+    )
 
 LAYOUT_SOURCE_GUESSED = 'guess'
 LAYOUT_SOURCE_CONFIG = 'config'
@@ -103,6 +115,54 @@ LAYOUT_SOURCE_REGISTRY = 'registry'
 LAYOUT_SOURCE_OVERRIDDEN = 'overridden'
 LAYOUT_SOURCE_MAPPING_MANDATED = 'mapping-mandated'
 
+class DummyLockableFiles(object):
+
+    def __init__(self, transport):
+        self._transport = transport
+
+    def create_lock(self):
+        pass
+
+    def break_lock(self):
+        pass
+
+    def leave_in_place(self):
+        pass
+
+    def dont_leave_in_place(self):
+        pass
+
+    def lock_write(self, token=None):
+        pass
+
+    def lock_read(self):
+        pass
+
+    def unlock(self):
+        pass
+
+    def is_locked(self):
+        """Return true if this LockableFiles group is locked"""
+        return False
+
+    def get_physical_lock_status(self):
+        """Return physical lock status.
+
+        Returns true if a lock is held on the transport. If no lock is held, or
+        the underlying locking mechanism does not support querying lock
+        status, false is returned.
+        """
+        return False
+
+    def get_transaction(self):
+        """Return the current active transaction.
+
+        If no transaction is active, this returns a passthrough object
+        for which all data is immediately flushed and no caching happens.
+        """
+        return transactions.PassThroughTransaction()
+
+
 class SvnRepositoryFormat(RepositoryFormat):
     """Repository format for Subversion repositories (accessed using svn_ra).
     """
@@ -128,8 +188,14 @@ class SvnRepositoryFormat(RepositoryFormat):
     def initialize(self, url, shared=False, _internal=False):
         raise bzr_errors.UninitializableFormat(self)
 
+    def get_foreign_tests_repository_factory(self):
+        from bzrlib.plugins.svn.tests.test_repository import ForeignTestsRepositoryFactory
+        return ForeignTestsRepositoryFactory()
+
     def check_conversion_target(self, target_repo_format):
-        return target_repo_format.rich_root_data
+        if not target_repo_format.rich_root_data:
+            raise bzr_errors.BadConversionTarget(
+                'Does not support rich root data.', target_repo_format)
 
 
 
@@ -314,7 +380,7 @@ class SvnRepository(ForeignRepository):
 
         assert isinstance(transport, Transport)
 
-        control_files = LockableFiles(transport, '', TransportLock)
+        control_files = DummyLockableFiles(transport)
         Repository.__init__(self, SvnRepositoryFormat(), bzrdir, control_files)
 
         self._cached_revnum = None
@@ -652,7 +718,7 @@ class SvnRepository(ForeignRepository):
     def __repr__(self):
         return '%s(%r)' % (self.__class__.__name__, self.base)
 
-    def _check(self, revision_ids):
+    def _check(self, revision_ids=None, callback_refs=None, check_repo=True):
         ret = SubversionRepositoryCheckResult(self)
         pb = ui.ui_factory.nested_progress_bar()
         try:
@@ -726,7 +792,7 @@ class SvnRepository(ForeignRepository):
                 todo.append(entry)
                 processed.add(entry)
         if lhs_history is None:
-            update_todo(todo, self._iter_reverse_revmeta_mapping_history(branch_path, revnum, to_revnum=0, mapping=mapping, pb=bp))
+            update_todo(todo, self._iter_reverse_revmeta_mapping_history(branch_path, revnum, to_revnum=0, mapping=mapping, pb=pb))
         else:
             update_todo(todo, lhs_history)
         i = 0
@@ -739,21 +805,21 @@ class SvnRepository(ForeignRepository):
             yield entry
             for rhs_parent_revid in revmeta.get_rhs_parents(mapping):
                 try:
-                    (_, rhs_parent_bp, rhs_parent_revnum), rhs_parent_mapping = self.lookup_revision_id(rhs_parent_revid, foreign_sibling=revmeta.get_foreign_revid())
+                    (_, rhs_parent_bp, rhs_parent_revnum), rhs_parent_mapping = self.lookup_bzr_revision_id(rhs_parent_revid, foreign_sibling=revmeta.get_foreign_revid())
                 except bzr_errors.NoSuchRevision:
                     pass
                 else:
                     update_todo(todo, self._iter_reverse_revmeta_mapping_history(rhs_parent_bp, rhs_parent_revnum, to_revnum=0, mapping=mapping, pb=pb))
 
-    def _iter_reverse_revmeta_mapping_history(self, branch_path, revnum, 
-        to_revnum, mapping, pb=None, limit=0): 
+    def _iter_reverse_revmeta_mapping_history(self, branch_path, revnum,
+        to_revnum, mapping, pb=None, limit=0):
         """Iterate over the history of a RevisionMetadata object.
 
         This will skip hidden revisions.
         """
         assert mapping is not None
         expected_revid = None
-        iter = self._revmeta_provider.iter_reverse_branch_changes(branch_path, 
+        iter = self._revmeta_provider.iter_reverse_branch_changes(branch_path,
             revnum, to_revnum=to_revnum, pb=pb, limit=limit)
         for revmeta in iter:
             (mapping, lhs_mapping) = revmeta.get_appropriate_mappings(mapping)
@@ -765,7 +831,7 @@ class SvnRepository(ForeignRepository):
             if (expected_revid is not None and
                 not revid in (None, expected_revid)):
                 # Need to restart, branch root has changed
-                (_, branch_path, revnum), mapping = self.lookup_revision_id(revid, foreign_sibling=revmeta.get_foreign_revid())
+                (_, branch_path, revnum), mapping = self.lookup_bzr_revision_id(revid, foreign_sibling=revmeta.get_foreign_revid())
                 iter = self._revmeta_provider.iter_reverse_branch_changes(branch_path, revnum, to_revnum=to_revnum, pb=pb, limit=limit)
             if not mapping.is_branch_or_tag(revmeta.branch_path):
                 return
@@ -774,11 +840,11 @@ class SvnRepository(ForeignRepository):
             mapping = lhs_mapping
         if expected_revid is not None and expected_revid != NULL_REVISION:
             # Need to restart, branch root has changed
-            (_, branch_path, revnum), mapping = self.lookup_revision_id(expected_revid, foreign_sibling=revmeta.get_foreign_revid())
+            (_, branch_path, revnum), mapping = self.lookup_bzr_revision_id(expected_revid, foreign_sibling=revmeta.get_foreign_revid())
             for (revmeta, mapping) in self._iter_reverse_revmeta_mapping_history(branch_path, revnum, to_revnum=to_revnum, mapping=mapping, pb=pb, limit=limit):
                 yield (revmeta, mapping)
 
-    def iter_reverse_revision_history(self, revision_id, pb=None, limit=0, 
+    def iter_reverse_revision_history(self, revision_id, pb=None, limit=0,
                                       project=None):
         """Iterate backwards through revision ids in the lefthand history
 
@@ -787,10 +853,10 @@ class SvnRepository(ForeignRepository):
         """
         if revision_id in (None, NULL_REVISION):
             return
-        (uuid, branch_path, revnum), mapping = self.lookup_revision_id(revision_id, project=project)
+        (uuid, branch_path, revnum), mapping = self.lookup_bzr_revision_id(revision_id, project=project)
         assert uuid == self.uuid
         for revmeta, mapping in self._iter_reverse_revmeta_mapping_history(
-            branch_path, revnum, to_revnum=0, mapping=mapping, pb=pb, 
+            branch_path, revnum, to_revnum=0, mapping=mapping, pb=pb,
             limit=limit):
             if revmeta.is_hidden(mapping):
                 continue
@@ -821,7 +887,7 @@ class SvnRepository(ForeignRepository):
             return True
 
         try:
-            foreign_revid, _ = self.lookup_revision_id(revision_id, project=project)
+            foreign_revid, _ = self.lookup_bzr_revision_id(revision_id, project=project)
         except bzr_errors.NoSuchRevision:
             return False
 
@@ -866,7 +932,7 @@ class SvnRepository(ForeignRepository):
         return parent_map
 
     def _get_revmeta(self, revision_id):
-        (uuid, branch, revnum), mapping = self.lookup_revision_id(revision_id)
+        (uuid, branch, revnum), mapping = self.lookup_bzr_revision_id(revision_id)
         revmeta = self._revmeta_provider.lookup_revision(branch, revnum)
         return revmeta, mapping
 
@@ -918,7 +984,7 @@ class SvnRepository(ForeignRepository):
         assert isinstance(revnum, int)
         return self.lookup_foreign_revision_id((self.uuid, path, revnum), mapping)
 
-    def lookup_revision_id(self, revid, layout=None, ancestry=None, 
+    def lookup_bzr_revision_id(self, revid, layout=None, ancestry=None, 
                            project=None, foreign_sibling=None):
         """Parse an existing Subversion-based revision id.
 
@@ -1001,7 +1067,7 @@ class SvnRepository(ForeignRepository):
 
     def add_signature_text(self, revision_id, signature):
         """Add a signature text to an existing revision."""
-        (uuid, path, revnum), mapping = self.lookup_revision_id(revision_id)
+        (uuid, path, revnum), mapping = self.lookup_bzr_revision_id(revision_id)
         try:
             self.transport.change_rev_prop(revnum, SVN_REVPROP_BZR_SIGNATURE, signature)
         except subvertpy.SubversionException, (_, subvertpy.ERR_REPOS_DISABLED_FEATURE):
@@ -1184,7 +1250,7 @@ class SvnRepository(ForeignRepository):
             base_mapping = None
         else:
             base_foreign_revid, base_mapping = \
-                self.lookup_revision_id(parents[0], project=branch.project)
+                self.lookup_bzr_revision_id(parents[0], project=branch.project)
         return SvnCommitBuilder(self, branch.get_branch_path(), parents, 
                                 config, timestamp, timezone, committer, 
                                 revprops, revision_id, 
@@ -1202,40 +1268,6 @@ class SvnRepository(ForeignRepository):
         else:
             return iter(self.find_branchpaths(layout, from_revnum, to_revnum, project))
 
-    def find_children(self, path, revnum, pb=None):
-        """Find all children of path in revnum.
-
-        :param path:  Path to check
-        :param revnum:  Revision to check
-        """
-        assert isinstance(path, str), "invalid path"
-        path = path.strip("/")
-        conn = self.transport.connections.get(self.transport.get_svn_repos_root())
-        results = []
-        unchecked_dirs = set([path])
-        num_checked = 0
-        try:
-            while len(unchecked_dirs) > 0:
-                if pb is not None:
-                    pb.update("listing branch contents", num_checked, 
-                        num_checked+len(unchecked_dirs))
-                nextp = unchecked_dirs.pop()
-                num_checked += 1
-                try:
-                    dirents = conn.get_dir(nextp, revnum, subvertpy.ra.DIRENT_KIND)[0]
-                except subvertpy.SubversionException, (_, num):
-                    if num == subvertpy.ERR_FS_NOT_DIRECTORY:
-                        continue
-                    raise
-                for k, v in dirents.iteritems():
-                    childp = urlutils.join(nextp, k)
-                    if v['kind'] == subvertpy.NODE_DIR:
-                        unchecked_dirs.add(childp)
-                    results.append(childp)
-        finally:
-            self.transport.connections.add(conn)
-        return results
-
     def abort_write_group(self, suppress_errors=False):
         """See Repository.abort_write_group()."""
         self._write_group = None
