@@ -16,15 +16,9 @@
 
 """Tests for the bzr-svn plugin."""
 
-import os
 import subvertpy.tests
-import sys
 
 
-from bzrlib import (
-    osutils,
-    urlutils,
-    )
 from bzrlib.bzrdir import (
     BzrDir,
     )
@@ -32,11 +26,24 @@ from bzrlib.tests import (
     TestCaseInTempDir,
     )
 
+from bzrlib.plugins.svn.transport import (
+    svn_to_bzr_url,
+    )
+
 
 class SubversionTestCase(subvertpy.tests.SubversionTestCase,TestCaseInTempDir):
 
-    def make_repository(self, *args, **kwargs):
-        return subvertpy.tests.SubversionTestCase.make_repository(self, *args, **kwargs)
+    def make_repository(self, relpath, allow_revprop_changes=True):
+        """Create an SVN repository.
+
+        :param relpath: Relative path at which to create the repository.
+        :param allow_revprop_changes: Allow changes to SVN revision
+            properties.
+        :return: A bzr-friendly URL for the created repository.
+        """
+        return svn_to_bzr_url(
+            subvertpy.tests.SubversionTestCase.make_repository(self, 
+                relpath, allow_revprop_changes))
 
     def setUp(self):
         subvertpy.tests.SubversionTestCase.setUp(self)
@@ -84,7 +91,6 @@ class SubversionTestCase(subvertpy.tests.SubversionTestCase,TestCaseInTempDir):
 
 def test_suite():
     from unittest import TestSuite
-    
     from bzrlib.tests import TestUtil
 
     loader = TestUtil.TestLoader()
