@@ -89,7 +89,11 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         repos = Repository.open(repos_url)
         mapping = repos.get_mapping()
         rm_provider = repos._revmeta_provider
-        self.assertEqual({u"": (mapping.generate_file_id((repos.uuid, "", 0), u""), mapping.revision_id_foreign_to_bzr((repos.uuid, "", 0)), None)}, repos.get_fileid_map(rm_provider.get_revision("", 0), mapping))
+        ret = repos.get_fileid_map(rm_provider.get_revision("", 0), mapping).as_dict()
+        if mapping.is_branch(""):
+            self.assertEqual({u"": (mapping.generate_file_id((repos.uuid, "", 0), u""), mapping.revision_id_foreign_to_bzr((repos.uuid, "", 0)), None)}, ret)
+        else:
+            self.assertEquals({}, ret)
 
     def test_add_revision(self):
         repos_url = self.make_repository("a")
@@ -103,7 +107,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         self.assertFalse(repos.has_signature_for_revision_id("foo"))
 
     def test_set_signature(self):
-        repos_url = self.make_client("a", "dc")
+        repos_url = self.make_repository("a")
         repos = Repository.open(repos_url)
         cb = self.get_commit_editor(repos_url)
         cb.add_file("foo").modify("bar")
@@ -121,17 +125,28 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
                repos._revmeta_provider.iter_reverse_branch_changes("/", 20, 0))
 
     def test_follow_branch_switched_parents(self):
-        repos_url = self.make_client('a', 'dc')
-        self.build_tree({'dc/pykleur/trunk/pykleur': None})
-        self.client_add("dc/pykleur")
-        self.client_commit("dc", "initial")
-        self.build_tree({'dc/pykleur/trunk/pykleur/afile': 'contents'})
-        self.client_add("dc/pykleur/trunk/pykleur/afile")
-        self.client_commit("dc", "add file")
-        self.client_copy("dc/pykleur", "dc/pygments", 1)
-        self.client_delete('dc/pykleur')
-        self.client_update("dc")
-        self.client_commit("dc", "commit")
+        repos_url = self.make_repository('a')
+
+        cb = self.get_commit_editor(repos_url)
+        pykleur = cb.add_dir("pykleur")
+        trunk = pykleur.add_dir("pykleur/trunk")
+        nested = trunk.add_dir("pykleur/trunk/pykleur")
+        cb.close() #1
+        
+        cb = self.get_commit_editor(repos_url)
+        pykleur = cb.open_dir("pykleur")
+        trunk = pykleur.open_dir("pykleur/trunk")
+        nested = trunk.open_dir("pykleur/trunk/pykleur")
+        afile = nested.add_file("pykleur/trunk/pykleur/afile")
+        afile.modify("contents")
+        afile.close()
+        cb.close() #2
+
+        cb = self.get_commit_editor(repos_url)
+        cb.add_dir("pygments", "pykleur", 1)
+        cb.delete("pykleur")
+        cb.close() #3
+
         repos = Repository.open(repos_url)
         repos.set_layout(TrunkLayout(1))
         results = [(l.branch_path, l.get_paths(), l.revnum) for l in repos._revmeta_provider.iter_reverse_branch_changes("pygments/trunk", 3, 0)]
@@ -412,7 +427,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
 
         self.assertEqual([("tags/branchab", 2, True), 
                           ("tags/brancha", 2, True)], 
-                list(repos.find_branchpaths(TrunkLayout(0), to_revnum=2)))
+                list(repos.find_branchpaths(TrunkLayout(0), from_revnum=2, to_revnum=0)))
 
     def test_find_branchpaths_start_revno(self):
         repos_url = self.make_repository("a")
@@ -445,7 +460,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         self.client_delete("dc/tmp/branches/somefile")
         self.client_commit("dc", "My Message 2")
 
-        Repository.open(repos_url).find_branchpaths(TrunkLayout(2))
+        Repository.open(repos_url).find_branchpaths(TrunkLayout(2), from_revnum=2, to_revnum=0)
 
     def test_find_branchpaths_deleted_from_nobranch(self):
         repos_url = self.make_client("a", "dc")
@@ -459,7 +474,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         self.client_delete("dc/tmp/branches/somefile")
         self.client_commit("dc", "My Message 2")
 
-        Repository.open(repos_url).find_branchpaths(TrunkLayout(1))
+        Repository.open(repos_url).find_branchpaths(TrunkLayout(1), from_revnum=2, to_revnum=0)
 
     def test_find_branchpaths_moved_nobranch(self):
         repos_url = self.make_client("a", "dc")
@@ -479,7 +494,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
 
         self.assertEqual([("t2/branches/brancha", 2, True), 
                           ("t2/branches/branchab", 2, True)], 
-                list(repos.find_branchpaths(TrunkLayout(1), to_revnum=2)))
+                list(repos.find_branchpaths(TrunkLayout(1), to_revnum=2, from_revnum=2)))
 
     def test_find_branchpaths_root(self):
         repos_url = self.make_repository("a")
@@ -488,7 +503,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         repos.set_layout(RootLayout())
 
         self.assertEqual([("", 0, True)], 
-                list(repos.find_branchpaths(RootLayout(), to_revnum=0)))
+                list(repos.find_branchpaths(RootLayout(), to_revnum=0, from_revnum=0)))
 
     def test_find_branchpaths_no_later(self):
         repos_url = self.make_repository("a")
@@ -497,7 +512,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         repos.set_layout(RootLayout())
 
         self.assertEqual([("", 0, True)], 
-                list(repos.find_branchpaths(RootLayout(), to_revnum=0)))
+                list(repos.find_branchpaths(RootLayout(), to_revnum=0, from_revnum=0)))
 
     def test_find_branchpaths_trunk_empty(self):
         repos_url = self.make_repository("a")
@@ -506,7 +521,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         repos.set_layout(TrunkLayout(0))
 
         self.assertEqual([], 
-                list(repos.find_branchpaths(TrunkLayout(0), to_revnum=0)))
+                list(repos.find_branchpaths(TrunkLayout(0), to_revnum=0, from_revnum=0)))
 
     def test_find_branchpaths_trunk_one(self):
         repos_url = self.make_repository("a")
@@ -520,7 +535,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         dc.close()
 
         self.assertEqual([("trunk", 1, True)], 
-                list(repos.find_branchpaths(TrunkLayout(0), to_revnum=1)))
+                list(repos.find_branchpaths(TrunkLayout(0), from_revnum=1, to_revnum=0)))
 
     def test_find_branchpaths_removed(self):
         repos_url = self.make_repository("a")
@@ -538,9 +553,9 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         dc.close()
 
         self.assertEqual([("trunk", 1, True)], 
-                list(repos.find_branchpaths(TrunkLayout(0), to_revnum=1)))
-        self.assertEqual([("trunk", 1, False)], 
-                list(repos.find_branchpaths(TrunkLayout(0), to_revnum=2)))
+                list(repos.find_branchpaths(TrunkLayout(0), from_revnum=2, to_revnum=0)))
+        self.assertEqual([("trunk", 1, True)], 
+                list(repos.find_branchpaths(TrunkLayout(0), from_revnum=1, to_revnum=0)))
 
     def test_has_revision(self):
         bzrdir = self.make_client_and_bzrdir('d', 'dc')
@@ -781,11 +796,11 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         self.client_add("dc/bloe")
         self.client_commit("dc", "foobar")
         repository = Repository.open(repos_url)
-        self.assertRaises(NoSuchRevision, repository.lookup_revision_id, 
+        self.assertRaises(NoSuchRevision, repository.lookup_bzr_revision_id, 
             "nonexisting")
         mapping = repository.get_mapping()
         self.assertEqual(((repository.uuid, "bloe", 1), mapping),
-            repository.lookup_revision_id(
+            repository.lookup_bzr_revision_id(
                 repository.generate_revision_id(1, "bloe", mapping))[:2])
 
     def test_lookup_revision_id_invalid_uuid(self):
@@ -793,7 +808,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         repository = Repository.open(repos_url)
         mapping = repository.get_mapping()
         self.assertRaises(NoSuchRevision, 
-            repository.lookup_revision_id, 
+            repository.lookup_bzr_revision_id, 
                 mapping.revision_id_foreign_to_bzr(("invaliduuid", "", 0)))
         
     def test_check(self):
@@ -1004,7 +1019,7 @@ class TestSubversionMappingRepositoryWorks(SubversionTestCase):
         self.assertEquals([
             ('file', mapping.generate_file_id((b.repository.uuid, "", 1), u"foo"), set([revid])),
             ('inventory', None, [revid]),
-            ('signatures', None, set([revid])),
+            ('signatures', None, set([])),
             ('revisions', None, [revid])], ch)
 
     def test_fetch_file_from_non_branch(self):
