@@ -18,11 +18,9 @@
 import os
 import sys
 
-from bzrlib.bzrdir import format_registry
 import bzrlib.gpg
 from bzrlib.repository import Repository
 from bzrlib.tests.blackbox import ExternalBase
-from bzrlib.tests import KnownFailure
 
 from bzrlib.plugins.svn.convert import load_dumpfile
 from bzrlib.plugins.svn.layout.standard import RootLayout
@@ -58,7 +56,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
         repos_url = self.make_client('d', 'de')
         self.commit_something(repos_url)
         self.run_bzr("branch --stacked %s dc" % repos_url, retcode=3)
-        
+
     def test_log_empty(self):
         repos_url = self.make_repository('d')
         self.run_bzr('log %s' % repos_url)
@@ -73,7 +71,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_push_create_prefix(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         trunk = dc.add_dir("trunk")
         trunk.add_file("trunk/foo").modify()
@@ -89,7 +87,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_push(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         dc.add_file("foo").modify()
         dc.close()
@@ -102,7 +100,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_push_empty_existing(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         dc.add_dir("trunk")
         dc.close()
@@ -111,15 +109,12 @@ class TestBranch(SubversionTestCase, ExternalBase):
         self.build_tree({"dc/foo": "blaaaa"})
         self.run_bzr("add dc/foo")
         self.run_bzr("commit -m msg dc")
-        self.run_bzr_error([
-            # Ideally this should say:
-            # ['ERROR: Empty branch already exists at /trunk. Specify --overwrite or remove it before pushing.\n'
-             'ERROR: These branches have diverged.  Try using "merge" and then "push".\n'
-            ], ["push", "-d", "dc", "%s/trunk" % repos_url])
+        output, err = self.run_bzr("push -d dc %s/trunk" % repos_url, retcode=3)
+        self.assertTrue(('ERROR: These branches have diverged.  See "bzr help diverged-branches" for more information.\n' in err) or ('ERROR: These branches have diverged.  Try using "merge" and then "push".\n' in err))
 
     def test_dpush_empty_existing(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         dc.add_dir("trunk")
         dc.close()
@@ -151,7 +146,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_missing(self):
         repos_url = self.make_repository('d')
-        
+
         self.run_bzr("init dc")
 
         os.chdir("dc")
@@ -168,7 +163,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_push_overwrite(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         trunk = dc.add_dir('trunk')
         trunk.add_file("trunk/foo").modify()
@@ -189,7 +184,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_dpush(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         dc.add_file("foo").modify()
         dc.close()
@@ -202,7 +197,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_dpush_new(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         dc.add_file("foo").modify()
         dc.close()
@@ -217,7 +212,7 @@ class TestBranch(SubversionTestCase, ExternalBase):
 
     def test_dpush_wt_diff(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         dc.add_file("foo").modify()
         dc.close()
@@ -573,3 +568,18 @@ if len(sys.argv) == 2:
         os.chdir(cwd)
         os.chdir('shared/trunk')
         self.run_bzr('pull')
+
+    def test_svn_import_format(self):
+        svn_url = self.make_repository('d')
+        
+        self.run_bzr('svn-import --format 1.9-rich-root %s dc' % svn_url)
+        self.check_output("Repository branch (format: 1.14-rich-root or 1.9-rich-root)\nLocation:\n  shared repository: dc\n  repository branch: dc\n\nRelated branches:\n  parent branch: d\n", 'info dc')
+
+    def test_svn_layout(self):
+        svn_url = self.make_repository('d')
+
+        dc = self.get_commit_editor(svn_url)
+        dc.add_dir("trunk")
+        dc.close()
+        
+        self.check_output('Repository root: %s\nLayout: root\nBranch path: \nPush merged revisions: False\n' % svn_url, 'svn-layout %s' % svn_url)
