@@ -18,13 +18,15 @@
 
 import os
 import subvertpy
-from unittest import TestCase
 
 from bzrlib import urlutils
-from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
+from bzrlib.branch import (
+    Branch,
+    )
+from bzrlib.bzrdir import (
+    BzrDir,
+    )
 from bzrlib.errors import (
-    NoSuchFile,
     NoSuchRevision,
     NoSuchTag,
     NotBranchError,
@@ -32,13 +34,16 @@ from bzrlib.errors import (
     )
 from bzrlib.repository import Repository
 from bzrlib.revision import NULL_REVISION
+from bzrlib.tests import (
+    TestCase,
+    TestSkipped,
+    )
 from bzrlib.trace import mutter
 
 from bzrlib.plugins.svn.branch import (
     SvnBranchFormat,
     )
 from bzrlib.plugins.svn.convert import load_dumpfile
-from bzrlib.plugins.svn.mapping import SVN_PROP_BZR_REVISION_ID
 from bzrlib.plugins.svn.tests import SubversionTestCase
 
 class WorkingSubversionBranch(SubversionTestCase):
@@ -54,9 +59,14 @@ class WorkingSubversionBranch(SubversionTestCase):
         branch = Branch.open(repos_url)
         self.assertEqual("", branch.get_branch_path())
 
+    def test_get_child_submit_format_default(self):
+        repos_url = self.make_repository("a")
+        branch = Branch.open(repos_url)
+        self.assertEquals("svn", branch.get_child_submit_format())
+
     def test_tags_dict(self):
         repos_url = self.make_repository("a")
-       
+
         dc = self.get_commit_editor(repos_url)
         tags = dc.add_dir("tags")
         tags.add_dir("tags/foo")
@@ -98,7 +108,8 @@ class WorkingSubversionBranch(SubversionTestCase):
         dc.close()
 
         b = Branch.open(repos_url + "/trunk")
-        b.tags.set_tag(u"mytag", b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
+        b.tags.set_tag(u"mytag",
+            b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
 
         self.assertEquals(subvertpy.NODE_DIR, 
                 b.repository.transport.check_path("tags/mytag", 3))
@@ -199,7 +210,8 @@ class WorkingSubversionBranch(SubversionTestCase):
         dc.close()
 
         b = Branch.open(repos_url + "/trunk")
-        b.tags.set_tag(u"mytag", b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
+        b.tags.set_tag(u"mytag",
+            b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
 
         self.assertEquals(subvertpy.NODE_DIR, 
                 b.repository.transport.check_path("tags", 3))
@@ -320,13 +332,13 @@ class WorkingSubversionBranch(SubversionTestCase):
         repos_url = self.make_repository("a")
         branch = Branch.open(repos_url)
         self.assertRaises(NoSuchRevision, 
-                lambda: branch.lookup_revision_id("bla"))
+                lambda: branch.lookup_bzr_revision_id("bla"))
 
     def test_lookup_revision_id(self):
         repos_url = self.make_repository("a")
         branch = Branch.open(repos_url)
         self.assertEquals(0, 
-                branch.lookup_revision_id(branch.last_revision()))
+                branch.lookup_bzr_revision_id(branch.last_revision()))
 
     def test_set_parent(self):
         repos_url = self.make_repository('a')
@@ -377,7 +389,8 @@ class WorkingSubversionBranch(SubversionTestCase):
         dc.close()
 
         branch = Branch.open(repos_url+"/trunk")
-        self.assertRaises(NotImplementedError, branch.set_revision_history, ["nonexistantt"])
+        self.assertRaises(NotImplementedError,
+            branch.set_revision_history, ["nonexistantt"])
 
     def test_set_revision_history(self):
         repos_url = self.make_repository('a')
@@ -958,7 +971,9 @@ foohosts""")
 
 
 class BranchFormatTests(TestCase):
+
     def setUp(self):
+        super(BranchFormatTests, self).setUp()
         self.format = SvnBranchFormat()
 
     def test_initialize(self):
@@ -971,3 +986,13 @@ class BranchFormatTests(TestCase):
     def test_get_format_description(self):
         self.assertEqual("Subversion Smart Server", 
                          self.format.get_format_description())
+
+
+class ForeignTestsBranchFactory(object):
+
+    def make_empty_branch(self, transport):
+        raise TestSkipped
+
+    def make_branch(self, transport):
+        subvertpy.repos.create(transport.local_abspath("."))
+        return Branch.open(transport.base)
