@@ -15,36 +15,79 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+
 """Subversion fetch tests."""
 
-import os, sys
-import shutil
 
-from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
-from bzrlib.osutils import has_symlinks
-from bzrlib.repository import Repository
-from bzrlib.revision import NULL_REVISION
+import os
+import shutil
+import sys
+
+from bzrlib.branch import (
+    Branch,
+    )
+from bzrlib.bzrdir import (
+    BzrDir,
+    )
+from bzrlib.osutils import (
+    has_symlinks,
+    sha_string,
+    )
+from bzrlib.repository import (
+    Repository,
+    )
+from bzrlib.revision import (
+    NULL_REVISION,
+    )
 from bzrlib.tests import (
     KnownFailure,
     TestSkipped,
     )
-from bzrlib.trace import mutter
+from bzrlib.trace import (
+    mutter,
+    )
 
 from bzrlib.plugins.svn import (
     format,
     remote,
     )
-from bzrlib.plugins.svn.convert import load_dumpfile
-from bzrlib.plugins.svn.errors import InvalidFileName
+from bzrlib.plugins.svn.convert import (
+    load_dumpfile,
+    )
+from bzrlib.plugins.svn.errors import (
+    InvalidFileName,
+    )
+from bzrlib.plugins.svn.fetch import (
+   InterFromSvnRepository,
+   )
 from bzrlib.plugins.svn.layout.standard import (
     RootLayout,
     TrunkLayout,
     )
-from bzrlib.plugins.svn.tests import SubversionTestCase
-from bzrlib.plugins.svn.transport import SvnRaTransport
+from bzrlib.plugins.svn.tests import (
+    SubversionTestCase,
+    )
+from bzrlib.plugins.svn.transport import (
+    SvnRaTransport,
+    )
+
+
+class FetchTestCase(SubversionTestCase):
+
+    def get_inter(self, source, target):
+        return InterFromSvnRepository(source, target)
+
+    def copy_content(self, source, target, revision_id=None):
+        inter = self.get_inter(source, target)
+        return inter.copy_content(revision_id=revision_id)
+
+    def fetch(self, source, target, revision_id=None):
+        inter = self.get_inter(source, target)
+        return inter.fetch(revision_id=revision_id)
+
+
+class TestFetchWorks(FetchTestCase):
 
-class TestFetchWorks(SubversionTestCase):
     def test_fetch_trunk1(self):
         repos_url = self.make_repository('d')
 
@@ -58,7 +101,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(1))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_replace_from_branch(self):
         repos_url = self.make_repository('d')
@@ -116,7 +159,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_backslash(self):
         if sys.platform == 'win32':
@@ -132,7 +175,8 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        self.assertRaises(InvalidFileName, oldrepos.copy_content_into, newrepos)
+        self.assertRaises(InvalidFileName, self.copy_content, oldrepos, 
+                newrepos)
 
     def test_fetch_null(self):
         repos_url = self.make_repository('d')
@@ -140,7 +184,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(1))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos, NULL_REVISION)
+        self.copy_content(oldrepos, newrepos, NULL_REVISION)
 
     def test_fetch_copy_remove_old(self):
         repos_url = self.make_client('d', 'dc')
@@ -163,7 +207,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos = Repository.open(repos_url)
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_special_char(self):
         repos_url = self.make_repository('d')
@@ -177,7 +221,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_signature(self):
         repos_url = self.make_repository('d')
@@ -185,13 +229,12 @@ class TestFetchWorks(SubversionTestCase):
         trunk = dc.add_dir("trunk")
         trunk.add_file("trunk/bar").modify("data")
         dc.close()
-
         self.client_set_revprop(repos_url, 1, "bzr:gpg-signature", "SIGNATURE")
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         self.assertEquals("SIGNATURE", newrepos.get_signature_text(oldrepos.generate_revision_id(1, "trunk", oldrepos.get_mapping())))
 
     def test_fetch_file_branch(self):
@@ -204,7 +247,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_special_char_edit(self):
         repos_url = self.make_repository('d')
@@ -223,7 +266,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_special_char_child(self):
         repos_url = self.make_repository('d')
@@ -237,7 +280,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_special_char_modify(self):
         repos_url = self.make_repository('d')
@@ -256,7 +299,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_delete(self):
         repos_url = self.make_repository('d')
@@ -268,7 +311,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos = Repository.open(repos_url)
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
         dc = self.get_commit_editor(repos_url)
         foo = dc.open_dir("foo")
@@ -276,7 +319,7 @@ class TestFetchWorks(SubversionTestCase):
         dc.close()
 
         newrepos = Repository.open("f")
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(oldrepos.has_revision(oldrepos.generate_revision_id(2, "", mapping)))
 
@@ -296,7 +339,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         tree = newrepos.revision_tree(oldrepos.generate_revision_id(1, "", mapping))
         self.assertEquals(3, len(tree.inventory))
@@ -323,7 +366,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -365,7 +408,7 @@ class TestFetchWorks(SubversionTestCase):
         repo = to_bzrdir.create_repository()
         last_rev = oldrepos.generate_revision_id(3, "branch2", 
             oldrepos.get_mapping())
-        repo.fetch(oldrepos, last_rev)
+        self.fetch(oldrepos, repo, last_rev)
         self.assertEquals(repo.get_inventory(last_rev).root.file_id,
             oldrepos.get_mapping().generate_file_id(
                 (oldrepos.uuid, "branch1", 1), u""))
@@ -387,7 +430,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -423,7 +466,7 @@ class TestFetchWorks(SubversionTestCase):
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_replace_nordic(self):
         filename = os.path.join(self.test_dir, "dumpfile")
@@ -509,7 +552,7 @@ Node-action: delete
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -651,7 +694,7 @@ Node-copyfrom-path: u
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -798,7 +841,7 @@ Node-copyfrom-path: bla
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -979,7 +1022,7 @@ Node-copyfrom-path: bla
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1121,7 +1164,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1285,7 +1328,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1337,7 +1380,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         lastrevid = oldrepos.generate_revision_id(4, "branches/1.0", oldrepos.get_mapping())
         tree = newrepos.revision_tree(lastrevid)
         self.assertTrue(tree.path2id("dir1/file.txt") is not None)
@@ -1360,7 +1403,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
         branch = Branch.open("%s/branches/mybranch" % repos_url)
         mapping = oldrepos.get_mapping()
@@ -1389,7 +1432,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
         branch = Branch.open("%s/trunk" % repos_url)
         self.assertEqual([oldrepos.generate_revision_id(2, "trunk", oldrepos.get_mapping())],
@@ -1412,7 +1455,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
         branch = Branch.open("%s/trunk" % repos_url)
         if oldrepos.get_mapping().is_branch("old-trunk"):
@@ -1443,7 +1486,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_all(self):
         repos_url = self.make_repository('d')
@@ -1473,7 +1516,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
         mapping = oldrepos.get_mapping()
 
@@ -1572,8 +1615,8 @@ Node-copyfrom-path: x
         dir2 = BzrDir.create("g", format.get_rich_root_format())
         newrepos1 = dir1.create_repository()
         newrepos2 = dir2.create_repository()
-        oldrepos.copy_content_into(newrepos1)
-        oldrepos.copy_content_into(newrepos2)
+        self.copy_content(oldrepos, newrepos1)
+        self.copy_content(oldrepos, newrepos2)
         mapping = oldrepos.get_mapping()
         inv1 = newrepos1.get_inventory(
                 oldrepos.generate_revision_id(1, "", mapping))
@@ -1597,7 +1640,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1623,7 +1666,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         inv1 = newrepos.get_inventory(
                 oldrepos.generate_revision_id(1, "", mapping))
@@ -1648,14 +1691,23 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
         inv1 = newrepos.get_inventory(
                 oldrepos.generate_revision_id(1, "", mapping))
-        self.assertEqual('symlink', inv1[inv1.path2id("mylink")].kind)
-        self.assertEqual('bla', inv1[inv1.path2id("mylink")].symlink_target)
+        ie = inv1[inv1.path2id("mylink")]
+        self.assertEqual('symlink', ie.kind)
+        self.assertEqual('bla', ie.symlink_target)
+        self.assertEquals(None, ie.text_sha1)
+        key = (ie.file_id, ie.revision)
+        newrepos.lock_read()
+        try:
+            self.assertEquals(sha_string(""), 
+                newrepos.texts.get_sha1s([key])[key])
+        finally:
+            newrepos.unlock()
 
     def test_fetch_symlink_with_newlines(self):
         if not has_symlinks():
@@ -1673,7 +1725,7 @@ Node-copyfrom-path: x
         oldrepos = Repository.open(repos_url)
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1695,7 +1747,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1721,7 +1773,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(2, "", mapping)))
@@ -1747,7 +1799,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(2, "", mapping)))
@@ -1771,7 +1823,7 @@ Node-copyfrom-path: x
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
         oldrepos.set_layout(RootLayout())
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1798,7 +1850,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertTrue(newrepos.has_revision(
             oldrepos.generate_revision_id(1, "", mapping)))
@@ -1811,6 +1863,39 @@ Node-copyfrom-path: x
         self.assertEqual(oldrepos.generate_revision_id(2, "", mapping), 
                          inv2[inv2.path2id("bla")].revision)
 
+    def test_fetch_hidden(self):
+        repos_url = self.make_repository('d')
+
+        dc = self.get_commit_editor(repos_url)
+        trunk = dc.add_dir("trunk")
+        trunk.add_file("trunk/bla").modify("data")
+        dc.close()
+
+        dc = self.get_commit_editor(repos_url)
+        branches = dc.add_dir("branches")
+        branch = branches.add_dir("branches/brancha", "trunk")
+        dc.close()
+
+        self.client_set_revprop(repos_url, 2, "bzr:hidden", "")
+        self.client_set_revprop(repos_url, 2, "bzr:root", "branches/brancha")
+
+        dc = self.get_commit_editor(repos_url)
+        branches = dc.open_dir("branches")
+        brancha = branches.open_dir("branches/brancha")
+        brancha.add_file("branches/brancha/lala")
+        dc.close()
+
+        oldrepos = Repository.open(repos_url)
+        oldrepos.set_layout(TrunkLayout(0))
+        dir = BzrDir.create("f", format.get_rich_root_format())
+        newrepos = dir.create_repository()
+        self.copy_content(oldrepos, newrepos)
+
+        mapping = oldrepos.get_mapping()
+        self.assertTrue(newrepos.has_revision(mapping.revision_id_foreign_to_bzr((oldrepos.uuid, "branches/brancha", 3))))
+        self.assertTrue(newrepos.has_revision(mapping.revision_id_foreign_to_bzr((oldrepos.uuid, "trunk", 1))))
+        self.assertFalse(newrepos.has_revision(mapping.revision_id_foreign_to_bzr((oldrepos.uuid, "branches/brancha", 2))))
+
     def test_fetch_svk_merge(self):
         repos_url = self.make_repository('d')
 
@@ -1834,7 +1919,7 @@ Node-copyfrom-path: x
 
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
         mapping = oldrepos.get_mapping()
 
@@ -1880,7 +1965,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos, "revid4")
+        self.copy_content(oldrepos, newrepos, "revid4")
         from bzrlib.plugins.svn.mapping3.base import BzrSvnMappingv3
         from bzrlib.plugins.svn.mapping3.scheme import TrunkBranchingScheme
         revid3 = oldrepos.generate_revision_id(3, "trunk", 
@@ -1896,7 +1981,7 @@ Node-copyfrom-path: x
         newrepos = dir.create_repository()
         from bzrlib.plugins.svn.mapping4 import BzrSvnMappingv4
         revid5 = oldrepos.generate_revision_id(5, "trunk", BzrSvnMappingv4())
-        oldrepos.copy_content_into(newrepos, revid5)
+        self.copy_content(oldrepos, newrepos, revid5)
         from bzrlib.plugins.svn.mapping3.base import BzrSvnMappingv3
         from bzrlib.plugins.svn.mapping3.scheme import TrunkBranchingScheme
         revid3 = oldrepos.generate_revision_id(3, "trunk", 
@@ -1927,7 +2012,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(RootLayout())
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertEquals(set([
             oldrepos.generate_revision_id(0, "", mapping),
@@ -1963,7 +2048,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
         self.assertEquals(set([
             oldrepos.generate_revision_id(1, "trunk", mapping),
@@ -2005,7 +2090,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_replace_self_open_older(self):
         repos_url = self.make_repository('d')
@@ -2040,7 +2125,7 @@ Node-copyfrom-path: x
         oldrepos.set_layout(TrunkLayout(0))
         dir = BzrDir.create("f", format.get_rich_root_format())
         newrepos = dir.create_repository()
-        oldrepos.copy_content_into(newrepos)
+        self.copy_content(oldrepos, newrepos)
 
     def test_fetch_crosscopy(self):
         repos_url = self.make_repository('d')
@@ -2081,7 +2166,7 @@ Node-copyfrom-path: x
         copyrev = oldrepos.generate_revision_id(2, "branches/abranch", mapping)
         prevrev = oldrepos.generate_revision_id(3, "branches/abranch", mapping)
         lastrev = oldrepos.generate_revision_id(4, "branches/abranch", mapping)
-        oldrepos.copy_content_into(newrepos, lastrev)
+        self.copy_content(oldrepos, newrepos, lastrev)
 
         inventory = newrepos.get_inventory(lastrev)
         self.assertEqual(prevrev, 
