@@ -37,17 +37,17 @@ from bzrlib.plugins.svn.mapping import (
     mapping_registry,
     )
 from bzrlib.plugins.svn.layout.standard import (
-    CustomLayout,
     RootLayout,
     TrunkLayout,
     )
 from bzrlib.plugins.svn.tests import SubversionTestCase
 
 class MockRepo(object):
+
     def __init__(self, mapping, uuid="uuid"):
         self.uuid = uuid
 
-    def lookup_revision_id(self, revid):
+    def lookup_bzr_revision_id(self, revid):
         ret = self.mapping.revision_id_foreign_to_bzr(revid)
         return ret, None
 
