@@ -13,6 +13,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import subvertpy
+
 from bzrlib.tests import (
     TestCase,
     )
@@ -111,6 +113,39 @@ class Trunk2LayoutTests(TestCase):
         self.assertEquals(False, self.layout.is_branch_parent("foo/bar/tags"))
 
 
+class TrunkVariableLayoutTests(TestCase):
+
+    def setUp(self):
+        TestCase.setUp(self)
+        self.layout = TrunkLayout(None)
+
+    def test_is_trunk_branch(self):
+        self.assertEquals(True, self.layout.is_branch("foo/bar/trunk"))
+        self.assertEquals(True, self.layout.is_branch("trunk"))
+
+    def test_is_foo_branch(self):
+        self.assertEquals(False, self.layout.is_branch("foo"))
+
+    def test_is_branch_parent_trunk(self):
+        self.assertEquals(True, self.layout.is_branch_parent("foo/bar/trunk"))
+
+    def test_is_branch_parent_lev2(self):
+        self.assertEquals(True, self.layout.is_branch_parent("foo/bar"))
+
+    def test_is_branch_parent_lev1(self):
+        self.assertEquals(True, self.layout.is_branch_parent("foo"))
+
+    def test_is_branch_parent_lev3(self):
+        self.assertEquals(True, self.layout.is_branch_parent("foo/bar/blie"))
+
+    def test_is_branch_parent_branches(self):
+        self.assertEquals(True, self.layout.is_branch_parent("foo/bar/branches"))
+
+    def test_is_branch_parent_tags(self):
+        self.assertEquals(True, self.layout.is_branch_parent("bar/tags"))
+        self.assertEquals(True, self.layout.is_branch_parent("foo/bar/tags"))
+
+
 class WildcardLayoutTests(TestCase):
 
     def test_is_branch_simple(self):
@@ -145,3 +180,21 @@ class CustomLayoutTests(TestCase):
         x = CustomLayout(["foo/bar"])
         self.assertFalse(x.is_branch_parent("foo/bar"))
         self.assertTrue(x.is_branch_parent("foo"))
+
+    def test_get_branches(self):
+        x = CustomLayout(["foo/bar"])
+        class MockTransport(object):
+
+            def __init__(self, available_paths):
+                self._paths = available_paths
+
+            def check_path(self, path, revnum):
+                return self._paths.get(path, subvertpy.NODE_NONE)
+
+        class MockRepository(object):
+
+            def __init__(self, available_paths):
+                self.transport = MockTransport(available_paths)
+
+        self.assertEquals([(None, "foo/bar", "bar", None)],
+            x.get_branches(MockRepository({"foo/bar": subvertpy.NODE_DIR}), 3))
