@@ -46,16 +46,14 @@ from bzrlib.plugins.svn import (
 from bzrlib.plugins.svn.branch import (
     InterOtherSvnBranch,
     )
-from bzrlib.plugins.svn.errors import MissingPrefix
+from bzrlib.plugins.svn.errors import (
+    MissingPrefix,
+    )
 from bzrlib.plugins.svn.layout.standard import (
     RootLayout,
     TrunkLayout,
     )
-from bzrlib.plugins.svn.mapping import (
-    SVN_PROP_BZR_REVISION_ID,
-    )
 from bzrlib.plugins.svn.push import (
-    InterToSvnRepository,
     determine_branch_path,
     )
 from bzrlib.plugins.svn.tests import (
@@ -314,9 +312,10 @@ class TestPush(SubversionTestCase):
         if not osutils.has_symlinks():
             return
         os.symlink("bla", "dc/south")
-        assert os.path.islink("dc/south")
+        self.assertTrue(os.path.islink("dc/south"))
         wt = self.bzrdir.open_workingtree()
         wt.add('south')
+        self.assertEquals("bla", wt.get_symlink_target(wt.path2id("south")))
         wt.commit(message="Commit from Bzr")
 
         self.svndir.open_branch().pull(self.bzrdir.open_branch())
