@@ -21,6 +21,7 @@ import stat
 import subvertpy
 from subvertpy import ERR_FS_NOT_DIRECTORY
 from subvertpy.client import get_config
+import sys
 import urlparse
 import urllib
 
@@ -31,17 +32,17 @@ from bzrlib import (
     urlutils,
     )
 from bzrlib.errors import (
-    BzrError,    
+    BzrError,
+    DependencyNotPresent,
     FileExists,
     InvalidURL,
     NoSuchFile,
     NotLocalUrl,
     RedirectRequested,
-    TransportNotPossible, 
+    TransportNotPossible,
     )
 from bzrlib.trace import (
     mutter,
-    warning,
     )
 from bzrlib.transport import (
     Transport,
@@ -59,7 +60,7 @@ from bzrlib.plugins.svn.errors import (
     convert_error,
     )
 
-ERR_MALFORMED_FILE = getattr(subvertpy, "ERR_MALFORMED_FILE", 200002) 
+ERR_MALFORMED_FILE = getattr(subvertpy, "ERR_MALFORMED_FILE", 200002)
 
 try:
     svn_config = get_config()
@@ -74,12 +75,52 @@ except subvertpy.SubversionException, (msg, num):
 disabled_capabilities = set()
 
 
-# Don't run any tests on SvnTransport as it is not intended to be 
+# Don't run any tests on SvnTransport as it is not intended to be
 # a full implementation of Transport
 def get_test_permutations():
     return []
 
 
+def dav_options(transport, url):
+    from bzrlib.transport.http._urllib import HttpTransport_urllib, Request
+    if isinstance(transport, HttpTransport_urllib):
+        req = Request('OPTIONS', url, accepted_errors=[200, 403, 404, 405])
+        req.follow_redirections = True
+        resp = transport._perform(req)
+        if resp.code == 404:
+            raise NoSuchFile(transport._path)
+        if resp.code in (403, 405):
+            raise subvertpy.SubversionException("version control not supported for remote URL", subvertpy.ERR_RA_DAV_NOT_VCC)
+        return resp.headers.getheaders('DAV')
+    else:
+        try:
+            from bzrlib.transport.http._pycurl import PyCurlTransport
+        except DependencyNotPresent:
+            pass
+        else:
+            import pycurl
+            from cStringIO import StringIO
+            if isinstance(transport, PyCurlTransport):
+                conn = transport._get_curl()
+                conn.setopt(pycurl.URL, url)
+                transport._set_curl_options(conn)
+                conn.setopt(pycurl.CUSTOMREQUEST, 'OPTIONS')
+                conn.setopt(pycurl.NOBODY, 1)
+                header = StringIO()
+                data = StringIO()
+                conn.setopt(pycurl.HEADERFUNCTION, header.write)
+                conn.setopt(pycurl.WRITEFUNCTION, data.write)
+                transport._curl_perform(conn, header)
+                code = conn.getinfo(pycurl.HTTP_CODE)
+                if code == 404:
+                    raise NoSuchFile(transport._path)
+                if code in (403, 405):
+                    raise subvertpy.SubversionException("version control not supported for remote URL", subvertpy.ERR_RA_DAV_NOT_VCC)
+                headers = transport._parse_headers(header)
+                return headers.getheaders('DAV')
+    raise NotImplementedError
+
+
 def get_svn_ra_transport(bzr_transport):
     """Obtain corresponding SvnRaTransport for a stock Bazaar transport."""
     if isinstance(bzr_transport, SvnRaTransport):
@@ -89,22 +130,22 @@ def get_svn_ra_transport(bzr_transport):
     if ra_transport is not None:
         return ra_transport
 
-    svnbase = bzr_transport.external_url()
-    if svnbase.startswith("readonly+"):
-        svnbase = svnbase[len("readonly+"):]
-    # If this is a HTTP transport, use the existing connection to check 
+    svnbase = bzr_to_svn_url(bzr_transport.external_url())
+    # If this is a HTTP transport, use the existing connection to check
     # that the remote end supports version control.
-    from bzrlib.transport.http._urllib import HttpTransport_urllib, Request
-    if isinstance(bzr_transport, HttpTransport_urllib):
+    from bzrlib.transport.http import HttpTransportBase
+    if isinstance(bzr_transport, HttpTransportBase):
         url = bzr_transport._unsplit_url(bzr_transport._unqualified_scheme,
-            None, None, bzr_transport._host, bzr_transport._port, 
+            None, None, bzr_transport._host, bzr_transport._port,
             bzr_transport._path)
-        req = Request('OPTIONS', url, accepted_errors=[200]) 
-        req.follow_redirections = True
-        resp = bzr_transport._perform(req)
-        dav_entries = list(itertools.chain(*[entry.split(",") for entry in resp.headers.getheaders('DAV')]))
-        if not "version-control" in dav_entries:
-            raise subvertpy.SubversionException("version control not supported for remote URL", subvertpy.ERR_RA_DAV_NOT_VCC)
+        try:
+            dav_entries = dav_options(bzr_transport, url)
+        except NotImplementedError:
+            pass
+        else:
+            dav_entries = list(itertools.chain(*[entry.split(",") for entry in dav_entries]))
+            if not "version-control" in dav_entries:
+                raise subvertpy.SubversionException("version control not supported for remote URL", subvertpy.ERR_RA_DAV_NOT_VCC)
     # Save _svn_ra transport here so we don't have to connect again next time
     # we try to use bzr svn on this transport
     shared_connection = getattr(bzr_transport, "_shared_connection", None)
@@ -149,6 +190,9 @@ def bzr_to_svn_url(url):
 
     This will possibly remove the svn+ prefix.
     """
+    if url.startswith("readonly+"):
+        url = url[len("readonly+"):]
+
     if (url.startswith("svn+http://") or 
         url.startswith("svn+https://")):
         url = url[len("svn+"):] # Skip svn+
@@ -161,6 +205,18 @@ def bzr_to_svn_url(url):
     return url
 
 
+def svn_to_bzr_url(url):
+    """Convert a Subversion URL to a URL understood by Bazaar.
+
+    This mainly involves fixing file:// URLs on Windows.
+    """
+    if sys.platform == "win32":
+        # Subversion URLs have only two // after file: on Windows
+        if url.startswith("file://"):
+            url = "file:///" + url[len("file://"):]
+    return url
+
+
 class SubversionProgressReporter(object):
 
     def __init__(self, url):
@@ -188,10 +244,9 @@ def Connection(url, auth=None):
         progress_cb = SubversionProgressReporter(url).update
     else:
         progress_cb = None
+    assert type(url) == str
     try:
-        mutter('opening SVN RA connection to %r' % url)
-        ret = subvertpy.ra.RemoteAccess(url.encode('utf8'), 
-                auth=auth,
+        ret = subvertpy.ra.RemoteAccess(url, auth=auth,
                 client_string_func=bzrlib.plugins.svn.get_client_string,
                 progress_cb=progress_cb)
         if 'transport' in debug.debug_flags:
@@ -215,7 +270,7 @@ def Connection(url, auth=None):
             else:
                 raise AssertionError("Unable to parse error message: %s" % msg)
             raise RedirectRequested(source=_url_escape_uri(url),
-                                    target=_url_escape_uri(urlutils.join(url, new_url)), 
+                                    target=_url_escape_uri(urlutils.join(url, new_url)),
                                     is_permanent=True)
         raise convert_error(e)
     from bzrlib.plugins.svn import lazy_check_versions
@@ -303,6 +358,9 @@ class SvnRaTransport(Transport):
         else:
             return self.connections.get(self.svn_url)
 
+    def external_url(self):
+        return self.base
+
     def add_connection(self, conn):
         self.connections.add(conn)
 
@@ -486,8 +544,10 @@ class SvnRaTransport(Transport):
             relpath = ""
         try:
             (dirents, _, _) = self.get_dir(relpath, self.get_latest_revnum())
-        except subvertpy.SubversionException, (_, ERR_FS_NOT_DIRECTORY):
-            raise NoSuchFile(relpath)
+        except subvertpy.SubversionException, (_, num):
+            if num == ERR_FS_NOT_DIRECTORY:
+                raise NoSuchFile(relpath)
+            raise
         return dirents.keys()
 
     def check_path(self, path, revnum):
