@@ -25,10 +25,21 @@ import subvertpy
 ERR_WC_SCHEDULE_CONFLICT = getattr(subvertpy, "ERR_WC_SCHEDULE_CONFLICT", 155013)
 import subvertpy.wc
 from subvertpy import properties
-from subvertpy.wc import *
+from subvertpy.wc import (
+    SCHEDULE_ADD,
+    SCHEDULE_DELETE,
+    SCHEDULE_NORMAL,
+    SCHEDULE_REPLACE,
+    WorkingCopy,
+    check_wc,
+    get_adm_dir,
+    get_pristine_copy_path,
+    is_adm_dir,
+    revision_status,
+    )
 import urllib
 
-import bzrlib, bzrlib.add
+import bzrlib.add
 from bzrlib import (
     osutils,
     urlutils,
@@ -42,6 +53,7 @@ from bzrlib.bzrdir import (
     Converter,
     )
 from bzrlib.errors import (
+    BzrError,
     NotBranchError,
     NoSuchFile,
     NoSuchId,
@@ -60,7 +72,6 @@ from bzrlib.lockable_files import LockableFiles
 from bzrlib.lockdir import LockDir
 from bzrlib.revision import (
     NULL_REVISION,
-    ensure_null,
     )
 from bzrlib.trace import mutter
 from bzrlib.transport import get_transport
@@ -83,6 +94,7 @@ from bzrlib.plugins.svn.errors import (
     convert_svn_error,
     )
 from bzrlib.plugins.svn.format import (
+    SvnWorkingTreeDirFormat,
     get_rich_root_format,
     )
 from bzrlib.plugins.svn.mapping import (
@@ -104,6 +116,9 @@ from bzrlib.plugins.svn.tree import (
     SubversionTree,
     )
 
+class RepositoryRootUnknown(BzrError):
+    _fmt = "The working tree does not store the root of the Subversion repository."
+
 def update_wc(adm, basedir, conn, revnum):
     # FIXME: honor SVN_CONFIG_SECTION_HELPERS:SVN_CONFIG_OPTION_DIFF3_CMD
     # FIXME: honor SVN_CONFIG_SECTION_MISCELLANY:SVN_CONFIG_OPTION_USE_COMMIT_TIMES
@@ -190,7 +205,10 @@ class SvnWorkingTree(SubversionTree,WorkingTree):
 
     def get_branch_path(self, revnum=None):
         if revnum is None:
-            return self.bzrdir.branch_path
+            try:
+                return self.bzrdir.get_branch_path()
+            except RepositoryRootUnknown:
+                pass
         return self.branch.get_branch_path(revnum)
 
     @property
@@ -529,7 +547,7 @@ class SvnWorkingTree(SubversionTree,WorkingTree):
 
     def set_last_revision(self, revid):
         mutter('setting last revision to %r', revid)
-        rev = self.branch.lookup_revision_id(revid)
+        rev = self.branch.lookup_bzr_revision_id(revid)
         self._set_base(revid, rev)
 
     def set_parent_trees(self, parents_list, allow_leftmost_as_ghost=False):
@@ -551,7 +569,7 @@ class SvnWorkingTree(SubversionTree,WorkingTree):
             for merge in merges:
                 try:
                     svk_merges.add(_revision_id_to_svk_feature(merge,
-                        self.branch.repository.lookup_revision_id))
+                        self.branch.repository.lookup_bzr_revision_id))
                 except NoSuchRevision:
                     pass
 
@@ -800,6 +818,7 @@ class SvnWorkingTree(SubversionTree,WorkingTree):
         try:
             stat_result = _lstat(abspath.encode(osutils._fs_enc))
         except OSError, e:
+            import errno
             if getattr(e, 'errno', None) == errno.ENOENT:
                 # no file.
                 return ('missing', None, None, None)
@@ -875,7 +894,7 @@ class SvnWorkingTree(SubversionTree,WorkingTree):
         :param delta: An inventory delta (see apply_inventory_delta) describing
             the changes from the current left most parent revision to new_revid.
         """
-        rev = self.branch.lookup_revision_id(new_revid)
+        rev = self.branch.lookup_bzr_revision_id(new_revid)
         self._set_base(new_revid, rev)
 
         # TODO: Implement more efficient version
@@ -1003,9 +1022,6 @@ class SvnCheckout(BzrDir):
         finally:
             wc.close()
 
-        assert self.entry.url.startswith(self.entry.repos)
-        self.branch_path = self.entry.url[len(self.entry.repos):].strip("/")
-
         self._remote_branch_transport = None
         self._remote_repo_transport = None
         self._remote_bzrdir = None
@@ -1029,7 +1045,7 @@ class SvnCheckout(BzrDir):
         if self._remote_branch_transport is None:
             self._remote_branch_transport = SvnRaTransport(self.entry.url, from_transport=self._remote_repo_transport)
         return self._remote_branch_transport
-        
+
     def clone(self, path, revision_id=None, force_new_repo=False):
         raise NotImplementedError(self.clone)
 
@@ -1062,10 +1078,18 @@ class SvnCheckout(BzrDir):
         raise NoRepositoryPresent(self)
 
     def _find_repository(self):
+        if self.entry.repos is None:
+            return self.get_remote_bzrdir().find_repository()
         if self._remote_repo_transport is None:
             self._remote_repo_transport = SvnRaTransport(self.entry.repos, from_transport=self._remote_branch_transport)
-        return SvnRepository(self, self._remote_repo_transport, 
-                self.branch_path)
+        return SvnRepository(self, self._remote_repo_transport,
+                self.get_branch_path())
+
+    def get_branch_path(self):
+        if self.entry.repos is None:
+            raise RepositoryRootUnknown()
+        assert self.entry.url.startswith(self.entry.repos)
+        return self.entry.url[len(self.entry.repos):].strip("/")
 
     def needs_format_conversion(self, format=None):
         if format is None:
@@ -1093,14 +1117,16 @@ class SvnCheckout(BzrDir):
         repos = self._find_repository()
 
         try:
-            branch = SvnBranch(repos, self.branch_path)
+            branch = SvnBranch(repos, self.get_branch_path())
+        except RepositoryRootUnknown:
+            return self.get_remote_bzrdir().open_branch()
         except subvertpy.SubversionException, (_, num):
             if num == subvertpy.ERR_WC_NOT_DIRECTORY:
                 raise NotBranchError(path=self.base)
             raise
 
         branch.bzrdir = self.get_remote_bzrdir()
- 
+
         return branch
 
 
